--Don't worry about this
local addon, ns = ...
local Version = GetAddOnMetadata(addon, "Version")

--Cache Lua / WoW API
local format = string.format
local GetCVarBool = GetCVarBool
local ReloadUI = ReloadUI
local StopMusic = StopMusic

-- These are things we do not cache
-- GLOBALS: PluginInstallStepComplete, PluginInstallFrame

--Change this line and use a unique name for your plugin.
local mPlugin = "mMediaTag"

--Create references to ElvUI internals
local E, L, V, P, G = unpack(ElvUI)

--Create reference to LibElvUIPlugin
local EP = LibStub("LibElvUIPlugin-1.0")

--Create a new ElvUI module so ElvUI can handle initialization when ready
local mod = E:NewModule(mPlugin, "AceHook-3.0", "AceEvent-3.0", "AceTimer-3.0");

--This function will hold your layout settings
local function SetupLayout(layout)
	--[[
	--	PUT YOUR EXPORTED PROFILE/SETTINGS BELOW HERE
	--]]

	--LAYOUT GOES HERE



	--[[
		--If you want to modify the base layout according to
		-- certain conditions then this is how you could do it
		if layout == "tank" then
			--Make some changes to the layout posted above
		elseif layout == "dps" then
			--Make some other changes
		elseif layout == "healer" then
			--Make some different changes
		end
	--]]


	--[[
	--	This section at the bottom is just to update ElvUI and display a message
	--]]
	--Update ElvUI
	E:UpdateAll(true)
	--Show message about layout being set
	PluginInstallStepComplete.message = "Layout Set"
	PluginInstallStepComplete:Show()
end

--This function is executed when you press "Skip Process" or "Finished" in the installer.
local function InstallComplete()
	if GetCVarBool("Sound_EnableMusic") then
		StopMusic()
	end

	--Set a variable tracking the version of the addon when layout was installed
	E.db[mPlugin].install_version = Version

	ReloadUI()
end

--This is the data we pass on to the ElvUI Plugin Installer.
--The Plugin Installer is reponsible for displaying the install guide for this layout.
local InstallerData = {
	Title = format("|cff4beb2c%s %s|r", mPlugin, "Installation"),
	Name = mPlugin,
	--tutorialImage = "Interface\\AddOns\\MyAddOn\\logo.tga", --If you have a logo you want to use, otherwise it uses the one from ElvUI
	Pages = {
		[1] = function()
			PluginInstallFrame.SubTitle:SetFormattedText("Welcome to the installation for %s.", mPlugin)
			PluginInstallFrame.Desc1:SetText("This installation process will guide you through a few steps and apply settings to your current ElvUI profile. If you want to be able to go back to your original settings then create a new profile before going through this installation process.")
			PluginInstallFrame.Desc2:SetText("Please press the continue button if you wish to go through the installation process, otherwise click the 'Skip Process' button.")
			PluginInstallFrame.Option1:Show()
			PluginInstallFrame.Option1:SetScript("OnClick", InstallComplete)
			PluginInstallFrame.Option1:SetText("Skip Process")
		end,
		[2] = function()
			PluginInstallFrame.SubTitle:SetText("Layouts")
			PluginInstallFrame.Desc1:SetText("These are the layouts that are available. Please click a button below to apply the layout of your choosing.")
			PluginInstallFrame.Desc2:SetText("Importance: |cff07D400High|r")
			PluginInstallFrame.Option1:Show()
			PluginInstallFrame.Option1:SetScript("OnClick", function() SetupLayout("tank") end)
			PluginInstallFrame.Option1:SetText("Tank")
			PluginInstallFrame.Option2:Show()
			PluginInstallFrame.Option2:SetScript("OnClick", function() SetupLayout("healer") end)
			PluginInstallFrame.Option2:SetText("Healer")
			PluginInstallFrame.Option3:Show()
			PluginInstallFrame.Option3:SetScript("OnClick", function() SetupLayout("dps") end)
			PluginInstallFrame.Option3:SetText("DPS")
		end,
		[3] = function()
			PluginInstallFrame.SubTitle:SetText("Installation Complete")
			PluginInstallFrame.Desc1:SetText("You have completed the installation process.")
			PluginInstallFrame.Desc2:SetText("Please click the button below in order to finalize the process and automatically reload your UI.")
			PluginInstallFrame.Option1:Show()
			PluginInstallFrame.Option1:SetScript("OnClick", InstallComplete)
			PluginInstallFrame.Option1:SetText("Finished")
		end,
	},
	StepTitles = {
		[1] = "Welcome",
		[2] = "Layouts",
		[3] = "Installation Complete",
	},
	StepTitlesColor = {1, 1, 1},
	StepTitlesColorSelected = {0, 179/255, 1},
	StepTitleWidth = 200,
	StepTitleButtonWidth = 180,
	StepTitleTextJustification = "RIGHT",
}

--This function holds the options table which will be inserted into the ElvUI config
local function InsertOptions()
	E.Options.args.mPlugin = {
		order = 100,
		type = "group",
		name = "|CFF8E44ADm|r|CFF2ECC71Media|r|CFF3498DBTag|r",
		args = {
			header1 = {
				order = 1,
				type = "header",
				name = "|CFF8E44ADm|r|CFF2ECC71Media|r|CFF3498DBTag|r",
			},
			logo = {
				order = 2,
				type = 'description',
				name = "",
				fontSize = 'medium',
				image = function() return 'Interface\\AddOns\\ElvUI_mMediaTag\\media\\textures\\logo.tga', 320, 80 end,
			},
			header2 = {
				order = 3,
				type = "header",
				name = "|CFF8E44ADby|r |CFF2ECC71Blin|r|CFF3498DBkii|r",
			},
			description1 = {
				order = 4,
				type = "description",
				name = L["|CFF8E44ADm|r|CFF2ECC71Media|r|CFF3498DBTag|r is an addon for ElvUI with additional Statusbar textures, Tags, a game menu and professional menu for the datatext bars."],
			},
			spacer1 = {
				order = 5,
				type = "description",
				name = "\n\n\n",
			},
			 header3 = {
				 order = 6,
				 type = "header",
				 name = L["Configuration"],
			},
			profsettings = {
				order = 7,
				type = "group",
				name = L["Profession Menu"],
				args = {
					profup = {
						order = 1,
						type = 'toggle',
						name = L["Fold up"],
						desc = L["When activated, the Profession Menu opens upwards."],
						get = function(info)
							return E.db[mPlugin].mProfUp
						end,
						set = function(info, value)
							E.db[mPlugin].mProfUp = value
						end,
					},
					proficon = {
						order = 2,
						type = 'toggle',
						name = L["Symbols"],
						desc = L["Displays the icons for the professions in the menu."],
						get = function(info)
							return E.db[mPlugin].mProfIcon
						end,
						set = function(info, value)
							E.db[mPlugin].mProfIcon = value
						end,
					},
				},
			},
			menusettings = {
				order = 8,
				type = "group",
				name = L['System Menu'],
				args = {
					menuup = {
						order = 1,
						type = 'toggle',
						name = L["Fold up"],
						desc = L["When activated, the System Menu opens upwards."],
						get = function(info)
							return E.db[mPlugin].mMenuUp
						end,
						set = function(info, value)
							E.db[mPlugin].mMenuUp = value
						end,
					},
					-- menucolor = {
						-- order = 2,
						-- type = 'toggle',
						-- name = L["Colored System Menu"],
						-- desc = L["Activates a colored system menu."],
						-- get = function(info)
							-- return E.db[mPlugin].mMenuColor
						-- end,
						-- set = function(info, value)
							-- E.db[mPlugin].mMenuColor = value
						-- end,
					-- },
				},
			},
			-- header4 = {
				-- order = 8,
				-- type = "header",
				-- name = "Installation",
			-- },
			-- description2 = {
				-- order = 9,
				-- type = "description",
				-- name = "The installation guide should pop up automatically after you have completed the ElvUI installation. If you wish to re-run the installation process for this layout then please click the button below.",
			-- },
			-- spacer2 = {
				-- order = 10,
				-- type = "description",
				-- name = "",
			-- },
			-- install = {
				-- order = 11,
				-- type = "execute",
				-- name = "Install",
				-- desc = "Run the installation process.",
				-- func = function() E:GetModule("PluginInstaller"):Queue(InstallerData); E:ToggleOptionsUI(); end,
			-- },
		},
	}
end

--Create a unique table for our plugin
P[mPlugin] = {	
	['mProfUp'] = false,
	['mProfIcon'] = true,
	['mMenuUp'] = false,
	['mMenuColor'] = true,
}

--This function will handle initialization of the addon
function mod:Initialize()
	--Initiate installation process if ElvUI install is complete and our plugin install has not yet been run
	-- if E.private.install_complete and E.db[mPlugin].install_version == nil then
		-- E:GetModule("PluginInstaller"):Queue(InstallerData)
	-- end

	--Insert our options table when ElvUI config is loaded
	EP:RegisterPlugin(addon, InsertOptions)
end

--Register module with callback so it gets initialized when ready
E:RegisterModule(mod:GetName())
